[![Build Status](https://travis-ci.org/usgs/shakecast-aebm.svg?branch=master)](https://travis-ci.org/usgs/shakecast-aebm)
[![codecov](https://codecov.io/gh/usgs/shakecast-aebm/branch/master/graph/badge.svg)](https://codecov.io/gh/usgs/shakecast-aebm) 

A Python package for estimating potential impact to a structure using HAZUS's Advanced Engineering Building Module. Potentially useful for engineering research, but developed for integration with [ShakeCast](www.github.com/usgs/shakecast)
